# OpenBB Deribit Provider Extension

## Coverage

- obb.derivatives.options.chains
  - Support for symbols:
    - BTC
    - ETH
    - XRP
    - SOL
    - BNB
    - PAXG
- obb.derivatives.futures.curve
  - Support for symbols:
    - BTC
    - ETH
    - PAXG
- obb.derivatives.futures.historical
  - Support for symbols (Perpetual Futures):
    - ADAUSDC
    - ALGOUSDC
    - AVAXUSDC
    - BCHUSDC
    - BNBUSDC
    - BTC
    - BTCUSDC
    - BTCUSDT
    - DOGEUSDC
    - DOTUSDC
    - ETH
    - ETHUSDC
    - ETHUSDT
    - LINKUSDC
    - LTCUSDC
    - NEARUSDC
    - PAXGUSDC
    - SOLUSDC
    - TRXUSDC
    - UNIUSDC
    - XRPUSDC
  - Additional symbols include all Deribit instrument names of current open contracts for BTC, ETH, and PAXG futures.
- obb.derivatives.futures.instruments
  - Reference data for all current futures instruments.
- obb.derivatives.futures.info
  - Key stats by symbol (multiple items allowed).
